TheCannon
=========

This is the code associated with *The Cannon*, a new data-driven method for 
determining stellar labels (physical parameters and chemical abundances) from
stellar spectra in the context of vast spectroscopic surveys. It closely 
follows the method outlined in Ness et al. 2015, although some minor changes 
have been made. A list of these changes can be found in Ho et al. 
(in prep.)   

Authors
-------

* **Anna Ho** (MPIA)
* **Melissa Ness** (MPIA)
* **David W. Hogg** (NYU CCPP)(MPIA)
* **Hans-Walter Rix** (MPIA)

License and Citation
--------------------

Copyright 2015 the authors. TheCannon is open-source software released under 
the MIT License. See the file ``LICENSE`` for details.

A condition on using this code for any academic purpose is citation of
Ness et al. 2015 (arXiv:1501.07604) and Ho et al. (in preparation). 

Projects
--------

* Cross-calibration of APOGEE and LAMOST: putting LAMOST spectra onto the 
APOGEE parameter scale.
